Function plot.cyclo.clust provides options to visualize the cyclical- time constrained clusters produced by cyclo.hclust.

# S3 method for class 'cyclo.clust'
plot(
  x,
  k,
  clust.colors = NULL,
  cyclical.factor = 1,
  add.means = F,
  lines.means = F,
  add.points = F,
  ...
)

Arguments

x

a cyclical-time-constrained clustering object, as provided by function cyclo.hclust.

k

an integer scalar with the desired number of clusters (as in cutree).

clust.colors

a vector of colors of the same length as k. Defaults to shades of grey if not provided.

cyclical.factor

a factor allowing to convert from the unit used in linear time to the unit used in cyclical time used for display.

add.means

boolean. Should the cluster mean positions be displayed?

lines.means

boolean. Should the means be joined by lines?

add.points

boolean. Should the raw data points be displayed?

...

other parameters parsed to function plot.

Author

Nicolas Djeghri, UBO

Examples

#WRITE SOME R CODE IN THERE!!!