Function cluster.cyclo.pos computes indices of cluster position
(start, end, mean and range) of cyclical-time-constrained clusters along
different cycles.
cluster.cyclo.pos(x, k)a cyclical-time-constrained clustering object, as provided by function cyclo.hclust.
an integer scalar with the desired number of clusters (as in cutree).
An object of class list, containing:
means: A table containing the mean position of each cluster in each cycle.
starts: A table containing the starting position of each cluster along each cycle.
ends: A table containing the ending position of each cluster along each cycle.
ranges: A table containing the ranges covered by each cluster within each cycle.
cycle.duration: The duration of a cycle.
A valuable aspect of a cyclical-time constrained clustering is the ability to
compare clusters' position in several cycles. Displacement of clusters can be
interpreted as advancing or delaying of a particular state along the cycles.
The function cluster.cyclo.pos compute four indices allowing related to
cluster position within cycles (see Value).
#WRITE SOME R CODE IN THERE!!!